package com.yovinchen.xlcs.acl.service.impl;

import cn.hutool.core.lang.UUID;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.yovinchen.xlcs.acl.mapper.AdminMapper;
import com.yovinchen.xlcs.acl.service.AdminService;
import com.yovinchen.xlcs.acl.service.RoleService;
import com.yovinchen.xlcs.common.utils.MD5;
import com.yovinchen.xlcs.model.acl.Admin;
import com.yovinchen.xlcs.vo.acl.AdminQueryVo;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * ClassName: AdminServiceImpl
 * Package: com.yovinchen.xlcs.acl.service.impl
 * 用户管理
 *
 * @author yovinchen
 * @since 2023/9/14 10:44
 */
@Slf4j
@Service
public class AdminServiceImpl extends ServiceImpl<AdminMapper, Admin> implements AdminService {

    @Autowired
    private AdminMapper userMapper;

    @Autowired
    private RoleService roleService;

    @Autowired
    private RedisTemplate redisTemplate;

    /**
     * 分页查询用户
     *
     * @param pageParam
     * @param userQueryVo
     * @return
     */
    @Override
    public IPage<Admin> selectPage(Page<Admin> pageParam, AdminQueryVo userQueryVo) {
        log.info("获取管理用户分页列表入参{}", pageParam.toString() + userQueryVo.toString());
        //获取用户名称条件值
        String name = userQueryVo.getName();
        //创建条件构造器
        LambdaQueryWrapper<Admin> wrapper = new LambdaQueryWrapper<>();
        if (!StringUtils.isEmpty(name)) {
            //封装条件
            wrapper.like(Admin::getName, name);
        }
        //调用mapper方法
        IPage<Admin> pageModel = baseMapper.selectPage(pageParam, wrapper);
        return pageModel;
    }

    /**
     * 后台登录
     *
     * @param username
     * @param password
     * @return
     */
    @Override
    public Map<String, Object> loginAdmin(String username, String password) {

        Integer i = baseMapper.selectCount(new LambdaQueryWrapper<Admin>().eq(Admin::getUsername, username)
                .eq(Admin::getPassword, MD5.encrypt(password)));
        if (i != 0) {
            // 验证通过，生成随机token
            String token = UUID.randomUUID()
                    .toString();
            redisTemplate.opsForValue()
                    .set(token, username);
            redisTemplate.expire(token, 5, TimeUnit.MINUTES); // 设置过期时间为五分钟
            // 返回包含token的结果
            Map<String, Object> map = new HashMap<>();
            map.put("token", token);
            return map;
        }
        return null;
    }

    @Override
    public Map<String, Object> getInfo(String token) {
        String username = (String) redisTemplate.opsForValue()
                .get(token);
        Admin admin = baseMapper.selectOne(new LambdaQueryWrapper<Admin>().eq(Admin::getUsername, username));
        Map<String, Object> map = new HashMap<>();
        map.put("name", admin.getName());
        map.put("avatar", "https://wpimg.wallstcn.com/f778738c-e4f8-4870-b634-56703b4acafe.gif");
        return map;
    }
}
