package com.yovinchen.xlcs.user.controller;

import com.yovinchen.xlcs.common.exception.xlcsException;
import com.yovinchen.xlcs.common.result.Result;
import com.yovinchen.xlcs.common.result.ResultCodeEnum;
import com.yovinchen.xlcs.model.user.User;
import com.yovinchen.xlcs.user.service.LoginService;
import com.yovinchen.xlcs.user.service.UserService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Map;

/**
 * ClassName: UserController
 * Package: com.yovinchen.xlcs.user.controller
 *
 * @author yovinchen
 * @since 2024/2/23 10:08
 */
@RestController
@RequestMapping("api/user/h5")
public class UserController {

    @Autowired
    private LoginService loginService;

    @Autowired
    private UserService userService;

    @ApiOperation(value = "手机号密码登录")
    @PostMapping("login")
    public Result login(@RequestBody Map<String, String> loginRequest) {
        String phone = loginRequest.get("phone");
        String password = loginRequest.get("password");
        Map<String, Object> map = loginService.login(phone, password);
        return Result.ok(map);
    }

    @PostMapping("auth/updateUser")
    @ApiOperation(value = "更新用户昵称与头像")
    public Result updateUser(@RequestBody User user) {
        userService.updateUser(user);
        return Result.ok(null);
    }

    @ApiOperation(value = "手机号密码注册")
    @PostMapping("register")
    public Result register(@RequestBody Map<String, String> loginRequest) {
        String phone = loginRequest.get("phone");
        String password = loginRequest.get("password");
        if (phone.isEmpty()) {
            throw new xlcsException(ResultCodeEnum.PHONE_NULL_ERROR);
        }
        Map<String, Object> map = userService.register(phone, password);
        return Result.ok(map);
    }
}
