package com.yovinchen.xlcs.user.service;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.yovinchen.xlcs.common.constant.RedisConst;
import com.yovinchen.xlcs.common.exception.xlcsException;
import com.yovinchen.xlcs.common.result.ResultCodeEnum;
import com.yovinchen.xlcs.common.utils.JwtHelper;
import com.yovinchen.xlcs.common.utils.MD5;
import com.yovinchen.xlcs.model.user.User;
import com.yovinchen.xlcs.vo.user.LeaderAddressVo;
import com.yovinchen.xlcs.vo.user.UserLoginVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * ClassName: LoginService
 * Package: com.yovinchen.xlcs.user.service
 *
 * @author yovinchen
 * @since 2024/2/23 10:09
 */
@Service
public class LoginService {

    @Autowired
    private UserService userService;

    @Autowired
    private RedisTemplate redisTemplate;

    public Map<String, Object> login(String phone, String password) {
        User user = userService.getOne(new LambdaQueryWrapper<User>().eq(User::getPhone, phone)
                .eq(User::getPassword, MD5.encrypt(password)));
        if (user == null) {
            throw new xlcsException(ResultCodeEnum.ACCOUNT_PASSWORD_ERROR);
        }
        // 根据userId查询配送点和配送员信息
        ////配送点  user表  user_delivery表
        ////配送员    leader表
        LeaderAddressVo leaderAddressVo = userService.getLeaderAddressByUserId(user.getId());

        //6 使用JWT工具根据userId和userName生成token字符串
        String token = JwtHelper.createToken(user.getId(), user.getNickName());

        //7 获取当前登录用户信息，放到Redis里面，设置有效时间
        UserLoginVo userLoginVo = userService.getUserLoginVo(user.getId());
        redisTemplate.opsForValue()
                .set(RedisConst.USER_LOGIN_KEY_PREFIX + user.getId(), userLoginVo, RedisConst.USERKEY_TIMEOUT, TimeUnit.DAYS);

        //8 需要数据封装到map返回
        Map<String, Object> map = new HashMap<>();
        map.put("user", user);
        map.put("token", token);
        map.put("leaderAddressVo", leaderAddressVo);
        return map;
    }
}
